==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/peering/kotlin/inputs/PeeringPropertiesExchangeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.peering.kotlin.inputs

import com.pulumi.azurenative.peering.inputs.PeeringPropertiesExchangeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The properties that define an exchange peering.
 * @property connections The set of connections that constitute an exchange peering.
 * @property peerAsn The reference of the peer ASN.
 */
public data class PeeringPropertiesExchangeArgs(
    public val connections: Output<List<ExchangeConnectionArgs>>? = null,
    public val peerAsn: Output<SubResourceArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.peering.inputs.PeeringPropertiesExchangeArgs> {
    override fun toJava(): com.pulumi.azurenative.peering.inputs.PeeringPropertiesExchangeArgs =
        com.pulumi.azurenative.peering.inputs.PeeringPropertiesExchangeArgs.builder()
            .connections(
                connections?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .peerAsn(peerAsn?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [PeeringPropertiesExchangeArgs].
 */
@PulumiTagMarker
public class PeeringPropertiesExchangeArgsBuilder internal constructor() {
    private var connections: Output<List<ExchangeConnectionArgs>>? = null

    private var peerAsn: Output<SubResourceArgs>? = null

    /**
     * @param value The set of connections that constitute an exchange peering.
     */
    @JvmName("nvqatdeakvamdewa")
    public suspend fun connections(`value`: Output<List<ExchangeConnectionArgs>>) {
        this.connections = value
    }

    @JvmName("gysnndxvffarutgv")
    public suspend fun connections(vararg values: Output<ExchangeConnectionArgs>) {
        this.connections = Output.all(values.asList())
    }

    /**
     * @param values The set of connections that constitute an exchange peering.
     */
    @JvmName("tmhrbtgubccqwkgi")
    public suspend fun connections(values: List<Output<ExchangeConnectionArgs>>) {
        this.connections = Output.all(values)
    }

    /**
     * @param value The reference of the peer ASN.
     */
    @JvmName("qkdydawxhhnpknfc")
    public suspend fun peerAsn(`value`: Output<SubResourceArgs>) {
        this.peerAsn = value
    }

    /**
     * @param value The set of connections that constitute an exchange peering.
     */
    @JvmName("qlhylgyddvvlvfqt")
    public suspend fun connections(`value`: List<ExchangeConnectionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.connections = mapped
    }

    /**
     * @param argument The set of connections that constitute an exchange peering.
     */
    @JvmName("yglgqtuvjqglsfqh")
    public suspend fun connections(argument: List<suspend ExchangeConnectionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ExchangeConnectionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.connections = mapped
    }

    /**
     * @param argument The set of connections that constitute an exchange peering.
     */
    @JvmName("jmudujlkyuioiwkd")
    public suspend fun connections(
        vararg
        argument: suspend ExchangeConnectionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ExchangeConnectionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.connections = mapped
    }

    /**
     * @param argument The set of connections that constitute an exchange peering.
     */
    @JvmName("nladhpxtlddnhfow")
    public suspend fun connections(argument: suspend ExchangeConnectionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ExchangeConnectionArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.connections = mapped
    }

    /**
     * @param values The set of connections that constitute an exchange peering.
     */
    @JvmName("rvtrllecktcbrwyf")
    public suspend fun connections(vararg values: ExchangeConnectionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.connections = mapped
    }

    /**
     * @param value The reference of the peer ASN.
     */
    @JvmName("bpcscbsapefqfhrq")
    public suspend fun peerAsn(`value`: SubResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.peerAsn = mapped
    }

    /**
     * @param argument The reference of the peer ASN.
     */
    @JvmName("gxukjfbcdvxawsro")
    public suspend fun peerAsn(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = SubResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.peerAsn = mapped
    }

    internal fun build(): PeeringPropertiesExchangeArgs = PeeringPropertiesExchangeArgs(
        connections = connections,
        peerAsn = peerAsn,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/peering/kotlin/inputs/PeeringPropertiesExchangeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.peering.kotlin.inputs

import com.pulumi.azurenative.peering.inputs.PeeringPropertiesExchangeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The properties that define an exchange peering.
 * @property connections The set of connections that constitute an exchange peering.
 * @property peerAsn The reference of the peer ASN.
 */
public data class PeeringPropertiesExchangeArgs(
    public val connections: Output<List<ExchangeConnectionArgs>>? = null,
    public val peerAsn: Output<SubResourceArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.peering.inputs.PeeringPropertiesExchangeArgs> {
    override fun toJava(): com.pulumi.azurenative.peering.inputs.PeeringPropertiesExchangeArgs =
        com.pulumi.azurenative.peering.inputs.PeeringPropertiesExchangeArgs.builder()
            .connections(
                connections?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .peerAsn(peerAsn?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [PeeringPropertiesExchangeArgs].
 */
@PulumiTagMarker
public class PeeringPropertiesExchangeArgsBuilder internal constructor() {
    private var connections: Output<List<ExchangeConnectionArgs>>? = null

    private var peerAsn: Output<SubResourceArgs>? = null

    /**
     * @param value The set of connections that constitute an exchange peering.
     */
    @JvmName("msnigdndpylnayms")
    public suspend fun connections(`value`: Output<List<ExchangeConnectionArgs>>) {
        this.connections = value
    }

    @JvmName("yxwalqckhvhogufw")
    public suspend fun connections(vararg values: Output<ExchangeConnectionArgs>) {
        this.connections = Output.all(values.asList())
    }

    /**
     * @param values The set of connections that constitute an exchange peering.
     */
    @JvmName("wufvosxlbbkepurq")
    public suspend fun connections(values: List<Output<ExchangeConnectionArgs>>) {
        this.connections = Output.all(values)
    }

    /**
     * @param value The reference of the peer ASN.
     */
    @JvmName("ewulrxlbiyoejqta")
    public suspend fun peerAsn(`value`: Output<SubResourceArgs>) {
        this.peerAsn = value
    }

    /**
     * @param value The set of connections that constitute an exchange peering.
     */
    @JvmName("ddhucrgfjymvvnwu")
    public suspend fun connections(`value`: List<ExchangeConnectionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.connections = mapped
    }

    /**
     * @param argument The set of connections that constitute an exchange peering.
     */
    @JvmName("fbduncmyhnitlfvx")
    public suspend fun connections(argument: List<suspend ExchangeConnectionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ExchangeConnectionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.connections = mapped
    }

    /**
     * @param argument The set of connections that constitute an exchange peering.
     */
    @JvmName("pifvdlwqskkphnfv")
    public suspend fun connections(
        vararg
        argument: suspend ExchangeConnectionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ExchangeConnectionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.connections = mapped
    }

    /**
     * @param argument The set of connections that constitute an exchange peering.
     */
    @JvmName("scwbjhlrxaesktju")
    public suspend fun connections(argument: suspend ExchangeConnectionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ExchangeConnectionArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.connections = mapped
    }

    /**
     * @param values The set of connections that constitute an exchange peering.
     */
    @JvmName("cndxkqpqsdqmvtnt")
    public suspend fun connections(vararg values: ExchangeConnectionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.connections = mapped
    }

    /**
     * @param value The reference of the peer ASN.
     */
    @JvmName("kengwuoytjurfqkb")
    public suspend fun peerAsn(`value`: SubResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.peerAsn = mapped
    }

    /**
     * @param argument The reference of the peer ASN.
     */
    @JvmName("tnmgrnmtdnjamicb")
    public suspend fun peerAsn(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = SubResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.peerAsn = mapped
    }

    internal fun build(): PeeringPropertiesExchangeArgs = PeeringPropertiesExchangeArgs(
        connections = connections,
        peerAsn = peerAsn,
    )
}
